@@ -228,7 +228,7 @@ bool QMPlay2CoreClass::isGlOnWindowForced()
 }
 #endif
 
-void QMPlay2CoreClass::init(bool loadModules, bool modulesInSubdirs, const QString &libPath, const QString &sharePath, const QString &profileName)
+void QMPlay2CoreClass::init(bool loadModulesAndGpu, bool modulesInSubdirs, const QString &libPath, const QString &sharePath, const QString &profileName)
 {
     if (!settingsDir.isEmpty())
         return;
@@ -317,15 +317,15 @@ void QMPlay2CoreClass::init(bool loadModules, bool modulesInSubdirs, const QStri
     av_log_set_callback(avQMPlay2LogHandler);
     avformat_network_init();
 
-#if defined(USE_VULKAN) && !defined(Q_OS_ANDROID)
-    settings->init("Renderer", "vulkan");
-#elif defined(USE_OPENGL)
-    settings->init("Renderer", "opengl");
-#endif
-    m_gpuInstance = GPUInstance::create();
-
-    if (loadModules)
+    if (loadModulesAndGpu)
     {
+#if defined(USE_VULKAN) && !defined(Q_OS_ANDROID)
+        settings->init("Renderer", "vulkan");
+#elif defined(USE_OPENGL)
+        settings->init("Renderer", "opengl");
+#endif
+        m_gpuInstance = GPUInstance::create();
+
         QFileInfoList pluginsList;
         QDir(settingsDir).mkdir("Modules");
         pluginsList += QDir(settingsDir + "Modules/").entryInfoList(QDir::Files);
@@ -347,7 +347,7 @@ void QMPlay2CoreClass::init(bool loadModules, bool modulesInSubdirs, const QStri
         }
 
         QStringList pluginsName;
-        for (const QFileInfo &fInfo : qAsConst(pluginsList))
+        for (const QFileInfo &fInfo : std::as_const(pluginsList))
         {
             if (QLibrary::isLibrary(fInfo.filePath()))
             {
@@ -410,8 +410,6 @@ void QMPlay2CoreClass::init(bool loadModules, bool modulesInSubdirs, const QStri
         }
     }
 
-    VideoFilters::init();
-
     connect(this, SIGNAL(restoreCursor()), this, SLOT(restoreCursorSlot()));
     connect(this, SIGNAL(waitCursor()), this, SLOT(waitCursorSlot()));
     connect(this, SIGNAL(busyCursor()), this, SLOT(busyCursorSlot()));
@@ -420,7 +418,7 @@ void QMPlay2CoreClass::quit()
 {
     if (settingsDir.isEmpty())
         return;
-    for (Module *pluginInstance : qAsConst(pluginsInstance))
+    for (Module *pluginInstance : std::as_const(pluginsInstance))
         delete pluginInstance;
     pluginsInstance.clear();
     videoFilters.clear();
@@ -594,9 +592,7 @@ void QMPlay2CoreClass::setLanguage()
         lang = QLocale::system().name();
     if (translator->load(lang, langDir))
     {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
         lang = QFileInfo(translator->filePath()).baseName();
-#endif
     }
     else
     {
@@ -681,20 +677,19 @@ QString QMPlay2CoreClass::getDescriptionForUrl(const QString &url)
     return getDataFromHash(url, descriptionsForUrl);
 }
 
-void QMPlay2CoreClass::loadPlaylistGroup(const QString &name, const QMPlay2CoreClass::GroupEntries &entries, bool enqueue)
+QString QMPlay2CoreClass::writePlaylistResource(const QString &name, const PlaylistEntries &playlistEntries)
 {
-    if (!entries.isEmpty())
+    if (playlistEntries.isEmpty())
+        return QString();
+
+    const QString resourceName = "QMPlay2://" + name + ".pls";
+    if (Playlist::write(playlistEntries, resourceName))
     {
-        const QString resourceName = "QMPlay2://" + name + ".pls";
-        Playlist::Entries playlistEntries;
-        for (const auto &entry : entries)
-            playlistEntries += {entry.first, entry.second};
-        if (Playlist::write(playlistEntries, resourceName))
-        {
-            modResource(resourceName, true);
-            emit processParam(enqueue ? "enqueue" : "open", resourceName);
-        }
+        modResource(resourceName, true);
+        return resourceName;
     }
+
+    return QString();
 }
 
 QString QMPlay2CoreClass::rendererName() const
