@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2024  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -24,6 +24,8 @@
 
 #include <vulkan/vulkan.hpp>
 
+#include <memory>
+
 namespace QmVk {
 
 using namespace std;
@@ -38,13 +40,15 @@ public:
     public:
         virtual ~SyncData() = default;
     };
-    using SyncDataPtr = std::unique_ptr<SyncData>;
+    using SyncDataPtr = unique_ptr<SyncData>;
 
 public:
     virtual void map(Frame &frame) = 0;
     virtual void clear() = 0;
 
-    virtual SyncDataPtr sync(const std::vector<Frame> &frames, vk::SubmitInfo *submitInfo = nullptr) = 0;
+    virtual SyncDataPtr sync(const vector<Frame> &frames, vk::SubmitInfo *submitInfo = nullptr) = 0;
+
+    virtual void updateInfo(const vector<Frame> &frames);
 
 protected:
     bool syncNow(vk::SubmitInfo &submitInfo);
